flite library

Classes

Database
Database to send sql commands, created during openDatabase
Foreign
Annotation used to mark a field as a foreign key.
Ignore
Annotation used to mark a field to be ignored in the generated SQL create query.
InsertParameters
Parameters used for insert operation in SQLite.
Primary
Annotation used to mark a field as the primary key.
ReadParameters
Parameters for reading data from SQLite.
Schema
Annotation used to define a schema for a SQLite table.
UpdateParameters
Parameters for updating data in SQLite.

Enums

Operation

Mixins

FliteProvider
A mixin providing core SQLite functionality for a schema class.

Constants

ignore → const Ignore
primary → const Primary