FliteProvider mixin
A mixin providing core SQLite functionality for a schema class.
To use this, mix it into a class that represents a SQLite table schema. Example:
class User with FliteProvider {
//..
}
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
insert_(
String table, Map< String, dynamic> json, InsertParameters params) → Future<int> - Insert into the table.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update_(
String table, Map< String, dynamic> json, UpdateParameters params) → Future<int> - Update the table.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited