InsertParameters class
Parameters used for insert operation in SQLite.
Constructors
- InsertParameters({ConflictAlgorithm? conflictAlgorithm, String? nullColumnHack})
Properties
- conflictAlgorithm → ConflictAlgorithm?
-
Specifies the conflict resolution algorithm to use if there is a conflict
when updating a row.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nullColumnHack → String?
-
Specifies a column to explicitly insert a NULL value when the values map is empty.
It is typically used when trying to insert a completely empty row into a table.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited